<?php
session_start();
define('SECURE_ACCESS', true);
require_once('../config.php');

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$justLoggedIn = isset($_SESSION['just_logged_in']) && $_SESSION['just_logged_in'] === true;
if ($justLoggedIn) {
    $_SESSION['just_logged_in'] = false;
}

if (isset($_POST['logout'])) {
    session_destroy();
    header("Location: login.php");
    exit();
}

// Aloldal meghatározása URL alapján
$page = 'home';
$allowedPages = ['home', 'users', 'pages', 'posts', 'stats', 'settings'];

if (isset($_GET['page']) && in_array($_GET['page'], $allowedPages)) {
    $page = $_GET['page'];
}

?>
<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Metin 2 Admin Felület</title>
    <style>
        body {
            margin: 0;
            padding: 0;
            font-family: 'Arial', sans-serif;
            background: url('img/adminbg.jpg') no-repeat center center fixed;
            background-size: cover;
            color: #fff;
            display: flex;
            flex-direction: column;
            align-items: center;
            min-height: 100vh;
        }
        #header {
            background: url('img/header.png') no-repeat center center;
            background-size: cover;
            width: 890px;
            height: 50px;
            display: flex;
            align-items: center;
            justify-content: space-around;
            margin-top: 20px;
        }
        #header a {
            color: #FFD700;
            text-decoration: none;
            padding: 5px 10px;
            font-weight: bold;
            text-transform: uppercase;
            font-size: 14px;
            position: relative;
            overflow: hidden;
        }
        #header a::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 0;
            width: 100%;
            height: 2px;
            background-color: #FFD700;
            transform: translateX(-100%);
            transition: transform 0.3s ease;
        }
        #header a:hover::after {
            transform: translateX(0);
        }
        #content {
            background: rgba(0, 0, 0, 0.7);
            margin: 20px auto;
            padding: 20px;
            border-radius: 5px;
            width: 850px;
            color: #fff;
            box-shadow: 0 0 10px rgba(255, 215, 0, 0.3);
        }
        #logout-form {
            margin-left: auto;
        }
        #logout-button {
            background: none;
            border: none;
            color: #FFD700;
            cursor: pointer;
            font-size: 14px;
            font-weight: bold;
            text-transform: uppercase;
            padding: 5px 10px;
            position: relative;
            overflow: hidden;
        }
        #logout-button::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 0;
            width: 100%;
            height: 2px;
            background-color: #FFD700;
            transform: translateX(-100%);
            transition: transform 0.3s ease;
        }
        #logout-button:hover::after {
            transform: translateX(0);
        }
        #loading {
            display: none;
            position: fixed;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            background: rgba(0, 0, 0, 0.8);
            color: #FFD700;
            padding: 20px;
            border-radius: 5px;
            z-index: 1000;
        }
    </style>
</head>
<body>
    <div id="header">
        <a href="?page=home">Vezérlőpult</a>
        <a href="?page=users">Felhasználók</a>
        <a href="?page=pages">Oldalak</a>
        <a href="?page=posts">Bejegyzések</a>
        <a href="?page=stats">Statisztika</a>
        <a href="?page=settings">Beállítások</a>
        <form id="logout-form" method="post">
            <button id="logout-button" type="submit" name="logout">Kijelentkezés</button>
        </form>
    </div>
    <div id="content">
        <?php include "pages/{$page}.php"; ?>
    </div>

    <div id="loading">Betöltés...</div>

    <audio id="loginSound" src="audio/loggedin.wav" preload="auto"></audio>

    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script>
    $(document).ready(function() {
        var justLoggedIn = <?php echo $justLoggedIn ? 'true' : 'false'; ?>;
        if (justLoggedIn) {
            var audio = document.getElementById('loginSound');
            audio.play();
        }

        // Menüpontokra kattintás kezelése
        $('#header a').click(function(e) {
            e.preventDefault();
            var page = $(this).attr('href').split('=')[1];
            loadPage(page);
        });

        function loadPage(page) {
            $('#loading').show();
            $.ajax({
                url: 'pages/' + page + '.php',
                method: 'GET',
                success: function(response) {
                    $('#content').html(response);
                    history.pushState(null, '', '?page=' + page);
                    // Az oldalspecifikus szkriptek futtatása
                    if (typeof pageScripts !== 'undefined' && typeof pageScripts[page] === 'function') {
                        pageScripts[page]();
                    }
                },
                error: function() {
                    $('#content').html('Hiba történt az oldal betöltése közben.');
                },
                complete: function() {
                    $('#loading').hide();
                }
            });
        }

        // Oldalspecifikus szkriptek objektuma
        var pageScripts = {
            pages: function() {
                $.ajax({
                    url: 'ajax_handler.php',
                    method: 'POST',
                    data: { action: 'test_ajax' },
                    dataType: 'json',
                    success: function(response) {
                        if(response.success) {
                            alert('Ajax teszt sikeres: ' + response.message);
                        } else {
                            alert('Ajax teszt sikertelen: ' + response.message);
                        }
                    },
                    error: function() {
                        alert('Hiba történt az Ajax kérés során.');
                    }
                });
            }
        };

        // Kezdeti oldal betöltése, ha szükséges
        var initialPage = '<?php echo $page; ?>';
        if (initialPage !== 'home') {
            loadPage(initialPage);
        }
    });
    </script>
</body>
</html>