<?php
session_start();
define('SECURE_ACCESS', true);
require_once('../config.php');

$loginFailed = false;

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = $_POST['email'];
    $password = $_POST['password'];

    try {
        $pdo = new PDO("mysql:host=" . DB_HOST . ";dbname=" . DB_NAME, DB_USER, DB_PASS);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        $stmt = $pdo->prepare("SELECT user_id, password, user_role FROM users WHERE user_email = ?");
        $stmt->execute([$email]);
        $user = $stmt->fetch();

        if ($user && password_verify($password, $user['password'])) {
            $_SESSION['user_id'] = $user['user_id'];
            $_SESSION['user_role'] = $user['user_role'];
            $_SESSION['just_logged_in'] = true;
            header("Location: index.php");
            exit();
        } else {
            $error = "Hibás email cím vagy jelszó!";
            $loginFailed = true;
        }
    } catch(PDOException $e) {
        $error = "Hiba történt: " . $e->getMessage();
        $loginFailed = true;
    }
}
?>
<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Bejelentkezés</title>
    <style>
        body {
            margin: 0;
            padding: 0;
            font-family: sans-serif;
            background: url('img/bg.jpg') no-repeat top center;
            background-size: cover;
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        
        .login-box {
            width: 400px;
            padding: 40px;
            background: rgba(0,0,0,.5);
            box-sizing: border-box;
            box-shadow: 0 15px 25px rgba(0,0,0,.6);
            border-radius: 10px;
        }
        
        .login-box h2 {
            margin: 0 0 30px;
            padding: 0;
            color: #fff;
            text-align: center;
        }
        
        .login-box .user-box {
            position: relative;
        }
        
        .login-box .user-box input {
            width: 100%;
            padding: 10px 0;
            font-size: 16px;
            color: #fff;
            margin-bottom: 30px;
            border: none;
            border-bottom: 1px solid #fff;
            outline: none;
            background: transparent;
        }
        
        .login-box .user-box label {
            position: absolute;
            top: 0;
            left: 0;
            padding: 10px 0;
            font-size: 16px;
            color: #fff;
            pointer-events: none;
            transition: .5s;
        }
        
        .login-box .user-box input:focus ~ label,
        .login-box .user-box input:valid ~ label,
        .login-box .user-box input:-webkit-autofill ~ label {
            top: -20px;
            left: 0;
            color: #ffd700;
            font-size: 12px;
        }
        
        .login-box .user-box input:-webkit-autofill,
        .login-box .user-box input:-webkit-autofill:hover,
        .login-box .user-box input:-webkit-autofill:focus,
        .login-box .user-box input:-webkit-autofill:active {
            -webkit-text-fill-color: #fff !important;
            -webkit-box-shadow: 0 0 0 30px rgba(0,0,0,0) inset !important;
            transition: background-color 5000s ease-in-out 0s;
        }
        
        .login-box button {
            position: relative;
            display: inline-block;
            padding: 10px 20px;
            color: #ffd700;
            font-size: 16px;
            text-decoration: none;
            text-transform: uppercase;
            overflow: hidden;
            transition: .5s;
            margin-top: 40px;
            letter-spacing: 4px;
            background: transparent;
            border: none;
            cursor: pointer;
        }
        
        .login-box button:hover {
            background: #ffd700;
            color: #fff;
            border-radius: 5px;
            box-shadow: 0 0 5px #ffd700,
                        0 0 25px #ffd700,
                        0 0 50px #ffd700,
                        0 0 100px #ffd700;
        }
        
        .login-box button span {
            position: absolute;
            display: block;
        }
        
        .login-box button span:nth-child(1) {
            top: 0;
            left: -100%;
            width: 100%;
            height: 2px;
            background: linear-gradient(90deg, transparent, #ffd700);
            animation: btn-anim1 1s linear infinite;
        }
        
        @keyframes btn-anim1 {
            0% {
                left: -100%;
            }
            50%,100% {
                left: 100%;
            }
        }
        
        .login-box button span:nth-child(2) {
            top: -100%;
            right: 0;
            width: 2px;
            height: 100%;
            background: linear-gradient(180deg, transparent, #ffd700);
            animation: btn-anim2 1s linear infinite;
            animation-delay: .25s
        }
        
        @keyframes btn-anim2 {
            0% {
                top: -100%;
            }
            50%,100% {
                top: 100%;
            }
        }
        
        .login-box button span:nth-child(3) {
            bottom: 0;
            right: -100%;
            width: 100%;
            height: 2px;
            background: linear-gradient(270deg, transparent, #ffd700);
            animation: btn-anim3 1s linear infinite;
            animation-delay: .5s
        }
        
        @keyframes btn-anim3 {
            0% {
                right: -100%;
            }
            50%,100% {
                right: 100%;
            }
        }
        
        .login-box button span:nth-child(4) {
            bottom: -100%;
            left: 0;
            width: 2px;
            height: 100%;
            background: linear-gradient(360deg, transparent, #ffd700);
            animation: btn-anim4 1s linear infinite;
            animation-delay: .75s
        }
        
        @keyframes btn-anim4 {
            0% {
                bottom: -100%;
            }
            50%,100% {
                bottom: 100%;
            }
        }
        
        .error {
            color: #ff0000;
            text-align: center;
            margin-bottom: 20px;
        }
    </style>
</head>
<body>
    <div class="login-box">
        <h2>Bejelentkezés</h2>
        <?php if(isset($error)): ?>
            <p class="error"><?php echo $error; ?></p>
        <?php endif; ?>
        <form method="post">
            <div class="user-box">
                <input type="email" name="email" required autocomplete="off">
                <label>Email cím</label>
            </div>
            <div class="user-box">
                <input type="password" name="password" required autocomplete="off">
                <label>Jelszó</label>
            </div>
            <button type="submit">
                <span></span>
                <span></span>
                <span></span>
                <span></span>
                Bejelentkezés
            </button>
        </form>
    </div>

    <audio id="failSound" src="audio/fail.wav" preload="auto"></audio>

    <script>
    document.addEventListener('DOMContentLoaded', (event) => {
        const inputs = document.querySelectorAll('.user-box input');
        
        inputs.forEach(input => {
            if (input.value !== '') {
                input.classList.add('has-content');
            }
            
            input.addEventListener('input', function() {
                if (this.value !== '') {
                    this.classList.add('has-content');
                } else {
                    this.classList.remove('has-content');
                }
            });
            
            // Trigger the input event on page load
            input.dispatchEvent(new Event('input'));
        });

        // Play fail sound if login failed
        var loginFailed = <?php echo $loginFailed ? 'true' : 'false'; ?>;
        if (loginFailed) {
            var audio = document.getElementById('failSound');
            audio.play();
        }
    });
    </script>
</body>
</html>